@@ -48,9 +48,9 @@ else:
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> str:
+            if not interaction.response.is_done():
+                await interaction.response.defer(ephemeral=True)
             ctx = await interaction.client.get_context(interaction)
-            if interaction and not interaction.response.is_done():
-                await ctx.defer(ephemeral=True)
             return await cls.convert(ctx, argument)
 
         @classmethod
